@@ -3,7 +3,7 @@ import numpy as np
 
 from secml_malware.attack.whitebox.c_fast_gradient_sign_evasion import CFastGradientSignMethodEvasion
 from secml_malware.models import CClassifierEnd2EndMalware
-from secml_malware.utils.extend_pe import create_int_list_from_x_adv
+from secml_malware.utils.pe_operations import create_int_list_from_x_adv
 
 
 class CKreukEvasion(CFastGradientSignMethodEvasion):
